' Four things to set up.  #1 -- PinPoint astrometric engine

' IMPORTANT
' ArcSecPerPixelHoriz and CatalogPath must be set correctly
' for your images and GSC file locations, respectively.
' Arc seconds per pixel can be calculated as
' 206 * CCD pixel size (microns) / telescope focal length (mm)
' The number doesn't have to be ultra-precise but it has to be in
' the ballpark.

Set p = CreateObject("PinPoint.Plate")
p.SigmaAboveMean = 4#         ' Amount above noise : default = 4.0
p.minimumBrightness = 200     ' Minimum star brightness: default = 200
p.CatalogMaximumMagnitude = 20#  ' Maximum catalog magnitude: default = 20.0
p.CatalogExpansion = 0.3      ' Area expansion of catalog to account for misalignment: default = 0.3
p.MinimumStarSize = 2         ' Minimum star size in pixels: default = 2
p.Catalog = 3                 ' GSC-ACT; accurate and easy to use
p.CatalogPath = "C:\\GSC"     ' Path to catalog; find both GSC and Tables directories under this folder
ArcSecPerPixel = 2            ' Arc-seconds per pixel on chip


' #2 -- Telescope driver

' Need to set this to the appropriate telescope model
' This will pop up a chooser box; you pick the telescope
' and set up the COM port etc.  You can experiment with
' the Simulator
Set ch = CreateObject("DriverHelper.Chooser")
ScopeProgID = ch.Choose("")
Set t = CreateObject(ScopeProgID)
t.Connected = True
Set ch = Nothing

targetra = t.RightAscension
TargetDec = t.Declination


' #3 -- MaxIm Camera object.

Set c = CreateObject("MaxIm.CCDCamera")
c.LinkEnabled = True


' Util object
Set u = CreateObject("DriverHelper.Util")


' Now, take a one-minute exposure, save to disk, repeat 100X
For I = 1 To 100
    c.Expose 60, 1
    While Not c.ImageReady
        u.WaitForMilliseconds 100
    Wend
    FileName = "C:\\Image" + Str(I) + ".fit"
    c.SaveImage FileName
   
    ' Realign every 10th image
    If I Mod 10 = 0 Then
        p.AttachFITS (FileName)

        ' Tell PinPoint approximately where the telescope is pointing
        p.RightAscension = targetra
        p.Declination = TargetDec

        p.ArcsecPerPixelHoriz = ArcSecPerPixel
        p.ArcsecPerPixelVert = ArcSecPerPixel
        p.FindImageStars
        p.FindCatalogStars
        p.Solve
        
        ' Tell telescope where it really is pointed
        t.SyncToCoordinates p.RightAscension, p.Declination
        
        ' Slew back to the right place
        t.SlewToCoordinates targetra, TargetDec
        p.DetachFITS
    End If
    
Next
